==> nextcloud-25.0.5.tgz: nextcloud/apps/suspicious_login/l10n/he.js <==
OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "התגלתה כניסה ממיקום חדש",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "התגלתה כניסה חדשה לחשבון שלך. כתובת ה־IP %s סווגה כחשודה. אם זה היה ניסיון כניסה שלך, ניתן להתעלם מההודעה הזאת. בכל מקרה אחר מוטב לך לשנות את הססמה שלך.",
    "Suspicious Login" : "כניסה חשודה",
    "New login detected" : "התגלתה כניסה חדשה",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "זיהוי ואזהרה מפני כתובות IP חשודות שנכנסות ל־Nextcloud\n\t",
    "Suspicious login detection" : "התגלתה כניסה חשודה",
    "The suspicious login app is enabled on this instance. It will keep track of IP addresses users successfully log in from and build a classifier that warns if a new login comes from a suspicious IP address." : "יישומון הכניסה החשודה פעיל בעותק זה. היישומון יעקוב אחר כתובות ה־IP דרכן משתמשים נכנסו בהצלחה ויבנה מסווג שמזהיר במקרה שיש כניסה חדשה מכתובת IP חשודה.",
    "Training data statistics" : "סטטיסטיקת נתוני אימון",
    "So far the app has captured {total} logins (including client connections), of which {distinct} are distinct (IP, UID) tuples." : "עד כה לכד היישומון {total} פעילויות כניסה (לרבות חיבורי לקוחות) מתוכם {distinct} הן צמדים ייחודיים של (IP, UID) - כתובת IP ומזהה ייחודי.",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Classifier model statistics" : "סטטיסטיקת מודל הסיווג",
    "No classifier model has been trained yet. This most likely means that you just enabled the app recently. Because the training of a model requires good data, the app waits until logins of at least {days} days have been captured." : "לא התבצע אימון סביב אף מודל סיווג. הסיבה לכך היא כפי הנראה העובדה שהפעלת את היישומון לאחרונה. כיוון שאימון מודל דורש נתונים איכותיים, היישומון ממתין עד שתתבצענה לכידת כניסות במשך {days} ימים.",
    "During evaluation, the latest model (trained {time}) has shown to capture {recall}% of all suspicious logins (recall), whereas {precision}% of the logins classified as suspicious are indeed suspicious (precision). Below you see a visualization of historic model performance." : "במהלך ההערכה, הוכח שהדגם העדכני ביותר (אומן ב־{time}) לוכד {recall}% מכל ניסיונות הכניסה החשודים (החזרה - recall), בעוד {precision}% מניסיונות הכניסה שמסווגים כחשודים הם אכן חשודים (דיוק - precision). להלן ניתן לצפות בעיבוד חזותי של ביצועי הדגם במבט היסטורי.",
    "Precision" : "דיוק",
    "Recall" : "לקרוא מחדש"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");

==> nextcloud-30.0.5.tgz: nextcloud/apps/suspicious_login/l10n/he.js <==
OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "התגלתה כניסה ממיקום חדש",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "התגלתה כניסה חדשה לחשבון שלך. כתובת ה־IP %s סווגה כחשודה. אם זה היה ניסיון כניסה שלך, ניתן להתעלם מההודעה הזאת. בכל מקרה אחר מוטב לך לשנות את הססמה שלך.",
    "Suspicious Login" : "כניסה חשודה",
    "New login detected" : "התגלתה כניסה חדשה",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "זיהוי ואזהרה מפני כתובות IP חשודות שנכנסות ל־Nextcloud\n\t",
    "Suspicious login detection" : "התגלתה כניסה חשודה",
    "The suspicious login app is enabled on this instance. It will keep track of IP addresses users successfully log in from and build a classifier that warns if a new login comes from a suspicious IP address." : "יישומון הכניסה החשודה פעיל בעותק זה. היישומון יעקוב אחר כתובות ה־IP דרכן משתמשים נכנסו בהצלחה ויבנה מסווג שמזהיר במקרה שיש כניסה חדשה מכתובת IP חשודה.",
    "Training data statistics" : "סטטיסטיקת נתוני אימון",
    "So far the app has captured {total} logins (including client connections), of which {distinct} are distinct (IP, UID) tuples." : "עד כה לכד היישומון {total} פעילויות כניסה (לרבות חיבורי לקוחות) מתוכם {distinct} הן צמדים ייחודיים של (IP, UID) - כתובת IP ומזהה ייחודי.",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Classifier model statistics" : "סטטיסטיקת מודל הסיווג",
    "No classifier model has been trained yet. This most likely means that you just enabled the app recently. Because the training of a model requires good data, the app waits until logins of at least {days} days have been captured." : "לא התבצע אימון סביב אף מודל סיווג. הסיבה לכך היא כפי הנראה העובדה שהפעלת את היישומון לאחרונה. כיוון שאימון מודל דורש נתונים איכותיים, היישומון ממתין עד שתתבצענה לכידת כניסות במשך {days} ימים.",
    "During evaluation, the latest model (trained {time}) has shown to capture {recall}% of all suspicious logins (recall), whereas {precision}% of the logins classified as suspicious are indeed suspicious (precision). Below you see a visualization of historic model performance." : "במהלך ההערכה, הוכח שהדגם העדכני ביותר (אומן ב־{time}) לוכד {recall}% מכל ניסיונות הכניסה החשודים (החזרה - recall), בעוד {precision}% מניסיונות הכניסה שמסווגים כחשודים הם אכן חשודים (דיוק - precision). להלן ניתן לצפות בעיבוד חזותי של ביצועי הדגם במבט היסטורי.",
    "Precision" : "דיוק",
    "Recall" : "לקרוא מחדש"
},
"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
